module Config.Pages.Debate.Arguments.Records.TransPeople exposing (..)

import Config.Pages.Debate.Arguments.Types exposing (..)
import Config.Helpers.Converters exposing (toTitleCase)


argumentTransPeople : Argument
argumentTransPeople =
    { argumentTitle = toTitleCase "Argument For Trans Identity"
    , propositionTitle = "A trans person of the male sex is a woman and a trans person with female sex is a man."
    , propositionReductio = ""
    , propositionSummary = "Virtually 100% of the debate surrounding trans identity is merely a trivial semantic disagreement about what constitutes a man or a woman. Below is a formal argument for characterization of a man and a women that maximally satisfies both parties and minimizes absurdities."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4Rx~1Wx)),(~6x(Qx~4Sx~1Wx)),(Ra~1Wa),(Sg~1Wg)|=(Pa~1Qg)"
    , argumentCertainty = 10
    , argumentImage = "transpeople"
    , argumentHashtags = []
   
    
    , isNewTabLink = False
    , definitionTable =
        [ { definiendum = "Male"
          , definiens = "the cluster of traits that associate with small, but not large, gametes."
          }
        , { definiendum = "Female"
          , definiens = "the cluster of traits that associate with large, but not small, gametes."
          }
        , { definiendum = "P(x)"
          , definiens = "(x) is a woman"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) is a man"
          }
        , { definiendum = "R(x)"
          , definiens = "(x) possesses a sufficiently greater sum of weighted traits that more closely associate with large gametes than weighted traits that associate with small gametes"
          }
        , { definiendum = "S(x)"
          , definiens = "(x) possesses a sufficiently greater sum of weighted traits that more closely associate with small gametes than weighted traits that associate with large gametes"
          }
        , { definiendum = "W(x)"
          , definiens = "(x) is over 18 years of age"
          }
        , { definiendum = "x"
          , definiens = "someone"
          }
        , { definiendum = "a"
          , definiens = "a trans person of the male sex"
          }
        , { definiendum = "g"
          , definiens = "a trans person of the female sex"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "Someone is a woman if, and only if, someone possesses a sufficiently greater sum of weighted traits that more closely associate with large gametes than weighted traits that associate with small gametes and someone is over 18 years of age."
                  , notation = "∀x(Px↔Rx∧Wx)"
                  }
                , { premise = "Someone is a man if, and only if, someone possesses a sufficiently greater sum of weighted traits that more closely associate with small gametes than weighted traits that associate with large gametes and someone is over 18 years of age."
                  , notation = "∀x(Qx↔Sx∧Wx)"
                  }
                , { premise = "A trans person of the male sex possesses a sufficiently greater sum of weighted traits that more closely associate with large gametes than weighted traits that associate with small gametes and a trans person with small gametes is over 18 years of age."
                  , notation = "Ra∧Wa"
                  }
                , { premise = "A trans person of the female sex possesses a sufficiently greater sum of weighted traits that more closely associate with small gametes than weighted traits that associate with large gametes and a trans person with large gametes is over 18 years of age."
                  , notation = "Sg∧Wg"
                  }
                ]
          , conclusion = "Therefore, a trans person of the male sex is a woman and a trans person with female sex is a man."
          , conclusionNotation = "Pa∧Qg"
          }
        ]
    }
