module Config.Pages.Debate.Arguments.Records.UnhealthyProcessedMeat exposing (..)

import Config.Helpers.Converters exposing (toTitleCase)
import Config.Pages.Debate.Arguments.Types exposing (..)


argumentUnhealthyProcessedMeat : Argument
argumentUnhealthyProcessedMeat =
    { argumentTitle = toTitleCase "Argument for Unhealthy Processed Meat"
    , propositionTitle = "Processed meat is  unhealthy."
    , propositionReductio = ""
    , propositionSummary = "Even when you account for factors that could plausibly influence the results, processed meat has been shown to consistently increase the risk of morbidity and mortality, strongly suggesting that they directly contribute to worse health outcomes, particularly with respect to colorectal cancer and heart disease."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4Qx)),(Qs)|=(Ps)"
    , argumentCertainty = 8
    , argumentImage = "processedmeat"
    , argumentHashtags = []
   
    
    , isNewTabLink = False
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) has a strong tendency to associate with an increased risk of morbidity and/or mortality after adjusting and/or controlling for relevant variables."
          }
        , { definiendum = "Q(x)"
          , definiens = "there is a dearth of epistemically countervailing data on (x)."
          }
        , { definiendum = "R(x)"
          , definiens = "it is more reasonable to believe that (x) is  unhealthy than it is to believe the opposite."
          }
        , { definiendum = "x"
          , definiens = "a food"
          }
        , { definiendum = "p"
          , definiens = "processed meat"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a food has a strong tendency to associate with an increased risk of morbidity and/or mortality after adjusting and/or controling for relevant variables and there is a dearth of epistemically countervailing data on that food, then it is more reasonable to believe that the food is healthy than it is to believe the opposite."
                  , notation = "∀x((Px∧Qx)→Rx)"
                  }
                , { premise = "Processed meat has a strong tendency to associate with an increased risk of morbidity and mortality after adjustment and/or controlling for relevant variables."
                  , notation = "Pp"
                  }
                , { premise = "There is a dearth of epistemically countervailing data on processed meat."
                  , notation = "Qp"
                  }
                ]
          , conclusion = "Therefore, it is more reasonable to believe that processed meat is unhealthy than it is to believe the opposite."
          , conclusionNotation = "Rp"
          }
        ]
    }
